DefaultNotFoundFailure class

404 — the resource does not exist.

Inheritance

Constructors

DefaultNotFoundFailure()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSubtitle(BuildContext context) String
Supporting detail line shown under getTitle.
override
getTitle(BuildContext context) String
Short, user-facing headline for this failure.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited