ErrorRegistry class abstract

Abstract error registry that can be implemented by different projects

Constructors

ErrorRegistry()

Properties

allEndpointsKey String
Returns the key for all endpoints
no setter
dioRegistry DioErrorRegistry
Returns the mapping for Dio exception types to failures
no setter
endpointRegistry ErrorModelRegistry
Returns the endpoint-specific error mappings
no setter
generalRegistry GeneralErrorRegistry
Returns the mapping for general exception types to failures
no setter
genericError Failure
Returns the default failure for unhandled cases
no setter
hashCode int
The hash code for this object.
no setterinherited
parsedEitherKey String
Returns the key for parsing the either from the response
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited